.. scheme-node:

======================
Scheme Node (``node``)
======================

.. automodule:: orangecanvas.scheme.node


.. autoclass:: SchemeNode
   :members:
   :exclude-members:
      title_changed,
      position_changed,
      progress_changed,
      processing_state_changed
   :member-order: bysource
   :show-inheritance:

   .. autoattribute:: title_changed(title)

   .. autoattribute:: position_changed((x, y))

   .. autoattribute:: progress_changed(progress)

   .. autoattribute:: processing_state_changed(state)
